documentationtools.APICrawler
=============================

.. inheritance-diagram:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler
   :private-bases:

.. autoclass:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.code_root

.. autoattribute:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.docs_root

.. autoattribute:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.module_crawler

.. autoattribute:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.prefix

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__call__

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__repr__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__str__

   .. note:: Inherited from `__builtin__.object`
